@@ -289,11 +289,16 @@ readAndUseDeviceInfoDatabase(AGDeviceInfo *devInfo,
         recordid_t id;
         int rc;
 
-        rc = dlp_ReadRecordByIndex(sd, database_id, 0, 
-                                   (void *)dev_db_info_buffer, 
-                                   &id, &dev_db_info_buffer_size, 
+#ifdef PILOT_LINK_0_12
+        rc = dlp_ReadRecordByIndex(sd, database_id, 0,
+                                   (void *)dev_db_info_buffer,
+                                   &id, &attr, &cat);
+#else
+        rc = dlp_ReadRecordByIndex(sd, database_id, 0,
+                                   (void *)dev_db_info_buffer,
+                                   &id, &dev_db_info_buffer_size,
                                    &attr, &cat);
-    
+#endif
 
         if (rc >= 0) {
             uint8 *p = dev_db_info_buffer;
@@ -613,9 +618,14 @@ readDeviceUserConfig32(int sd, int userConfigDBHandle, AGUserConfig **deviceUser
     uint8 buffer[BUFFERSIZE];
     AGBufferReader * r = NULL;
 
-    rc = dlp_ReadRecordByIndex(sd, userConfigDBHandle, 0, (void *)buffer, 
+#ifdef PILOT_LINK_0_12
+    rc = dlp_ReadRecordByIndex(sd, userConfigDBHandle, 0, (void *)buffer,
+                               &id, &attr, &cat);
+#else
+    rc = dlp_ReadRecordByIndex(sd, userConfigDBHandle, 0, (void *)buffer,
                                &id, &bufferSize, &attr, &cat);
-    
+#endif
+
     if (rc < 0) {
         if (verbose)
             printf("readDeviceUserConfig: dlp_ReadRecordByIndex , err = %d\n",
@@ -651,9 +661,14 @@ static int32 readDeviceUserConfig31(int sd, int userConfigDBHandle,
     uint8 buffer[BUFFERSIZE];
     AGBufferReader * r = NULL;
 
-    rc = dlp_ReadRecordByIndex(sd, userConfigDBHandle, 0, (void *)buffer, 
+#ifdef PILOT_LINK_0_12
+    rc = dlp_ReadRecordByIndex(sd, userConfigDBHandle, 0, (void *)buffer,
+                               &id, &attr, &cat);
+#else
+    rc = dlp_ReadRecordByIndex(sd, userConfigDBHandle, 0, (void *)buffer,
                                &id, &bufferSize, &attr, &cat);
-    
+#endif
+
     if (rc < 0) {
         if (verbose)
             printf("readDeviceUserConfig: dlp_ReadRecordByIndex , err = %d\n",
@@ -711,9 +726,14 @@ static void writeDeviceUserConfig(int sd,
             AGUserConfigWriteData(deviceUserConfig, (AGWriter*)w);
         }
 
-        result = dlp_ReadRecordByIndex(sd, userConfigDBHandle, 0, (void *)buffer, 
-                                   &id, &bufferSize, &attr, &cat);
-        
+#ifdef PILOT_LINK_0_12
+        result = dlp_ReadRecordByIndex(sd, userConfigDBHandle, 0, (void *)buffer,
+                                       &id, &attr, &cat);
+#else
+        result = dlp_ReadRecordByIndex(sd, userConfigDBHandle, 0, (void *)buffer,
+                                       &id, &bufferSize, &attr, &cat);
+#endif
+
         if (result < 0)
             id = 0;
 
@@ -1025,6 +1045,14 @@ getRecordBase(PalmSyncInfo *pInfo, AGBool modonly,  AGRecord **record,
     int idx   = pInfo->pilot_RecIndex++;
 
     result = (modonly) ?
+#ifdef PILOT_LINK_0_12
+        dlp_ReadNextModifiedRec (pInfo->sd, pInfo->pilot_rHandle, pInfo->pilot_buffer,
+                                 &pInfo->id, &idx, &att, &cat)
+        :
+        dlp_ReadRecordByIndex(pInfo->sd, pInfo->pilot_rHandle, idx,
+                              (void *)pInfo->pilot_buffer,
+                              &pInfo->id, &att, &cat);
+#else
         dlp_ReadNextModifiedRec (pInfo->sd, pInfo->pilot_rHandle, pInfo->pilot_buffer,
                                  &pInfo->id, &idx,
                                  &size, &att, &cat)
@@ -1032,7 +1060,8 @@ getRecordBase(PalmSyncInfo *pInfo, AGBool modonly,  AGRecord **record,
         dlp_ReadRecordByIndex(pInfo->sd, pInfo->pilot_rHandle, idx,
                               pInfo->pilot_buffer, &pInfo->id,
                               &size, &att, &cat);
-    
+#endif
+
     if (result < 0) {
         closeDatabase(pInfo);
         if (result == dlpErrNotFound) {
@@ -1384,6 +1413,14 @@ fill_in_versioninfo(int sd, AGExpansionVersion *vi)
         uint8 version_buffer[version_buffer_size];
 
 
+#ifdef PILOT_LINK_0_12
+        rc = dlp_ReadRecordByIndex(sd, database_id, 
+                                   0, 
+                                   (void *)version_buffer, 
+                                   &id, 
+                                   &attr, 
+                                   &cat);
+#else
         rc = dlp_ReadRecordByIndex(sd, database_id, 
                                    0, 
                                    (void *)version_buffer, 
@@ -1391,6 +1428,7 @@ fill_in_versioninfo(int sd, AGExpansionVersion *vi)
                                    &version_buffer_size,
                                    &attr, 
                                    &cat);
+#endif
 
         if (rc >= 0) {
             ClientVersion cv;
